==> balsa_2.3.0.orig.tar.gz: balsa-2.3.0/src/filter-export-callbacks.c <==
/* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
/* Balsa E-Mail Client
 * Copyright (C) 1997-2000 Stuart Parmenter and others,
 *                         See the file AUTHORS for a list.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option) 
 * any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

/*
 * Author : Emmanuel ALLAUD
 */

/*
 * FIXME : should have a combo box for mailbox name when selecting a move or copy action
 */

#include "config.h"

#include "balsa-app.h"
#include "filter-export.h"

#include "i18n.h"	/* Must come after balsa-app.h. */

/* To prevent user from silmultaneously edit/export filters */
extern gboolean fex_already_open;

void 
fex_destroy_window_cb(GtkWidget * widget,gpointer throwaway)
{
    fex_already_open=FALSE;
}

static void
fex_dialog_response_func(GtkTreeModel * model, GtkTreePath * path,
                         GtkTreeIter * iter, gpointer data)
{
    LibBalsaFilter *fil;
    gchar *str;

    gtk_tree_model_get(model, iter, 1, &fil, -1);
    str = g_strdup_printf("%s.siv", fil->name);
    if (!libbalsa_filter_export_sieve(fil, str))
        balsa_information(LIBBALSA_INFORMATION_ERROR,
                          _("Unable to export filter %s, "
                            "an error occured."), fil->name);
    g_free(str);
}

void
fex_dialog_response(GtkWidget * dialog, gint response, gpointer data)
{
    if (response == GTK_RESPONSE_OK) {  /* OK Button */
        GtkTreeSelection *selection =
            gtk_tree_view_get_selection(GTK_TREE_VIEW(data));

        gtk_tree_selection_selected_foreach(selection,
                                            fex_dialog_response_func,
                                            NULL);
    }
    gtk_widget_destroy(dialog);
}

==> balsa_2.3.13.orig.tar.gz: balsa-2.3.13/src/filter-export-callbacks.c <==
/* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
/* Balsa E-Mail Client
 * Copyright (C) 1997-2000 Stuart Parmenter and others,
 *                         See the file AUTHORS for a list.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option) 
 * any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

/*
 * Author : Emmanuel ALLAUD
 */

/*
 * FIXME : should have a combo box for mailbox name when selecting a move or copy action
 */

#include "config.h"

#include "balsa-app.h"
#include "filter-export.h"

#include "i18n.h"	/* Must come after balsa-app.h. */

/* To prevent user from silmultaneously edit/export filters */
extern gboolean fex_already_open;

void 
fex_destroy_window_cb(GtkWidget * widget,gpointer throwaway)
{
    fex_already_open=FALSE;
}

static void
fex_dialog_response_func(GtkTreeModel * model, GtkTreePath * path,
                         GtkTreeIter * iter, gpointer data)
{
    LibBalsaFilter *fil;
    gchar *str;

    gtk_tree_model_get(model, iter, 1, &fil, -1);
    str = g_strdup_printf("%s.siv", fil->name);
    if (!libbalsa_filter_export_sieve(fil, str))
        balsa_information(LIBBALSA_INFORMATION_ERROR,
                          _("Unable to export filter %s, "
                            "an error occurred."), fil->name);
    g_free(str);
}

void
fex_dialog_response(GtkWidget * dialog, gint response, gpointer data)
{
    if (response == GTK_RESPONSE_OK) {  /* OK Button */
        GtkTreeSelection *selection =
            gtk_tree_view_get_selection(GTK_TREE_VIEW(data));

        gtk_tree_selection_selected_foreach(selection,
                                            fex_dialog_response_func,
                                            NULL);
    }
    gtk_widget_destroy(dialog);
}
